

TPREC = -4

TRACKS = (
    'Mario Kart Stadium', 'Water Park', 'Sweet Sweet Canyon', 'Thwomp Ruins',
    'Mario Circuit', 'Toad Harbor', 'Twisted Mansion', 'Shy Guy Falls',
    'Sunshine Airport', 'Dolphin Shoals', 'Electrodrome', 'Mount Wario',
    'Cloudtop Cruise', 'Bone-Dry Dunes', "Bowser's Castle", 'Rainbow Road',
    'Wii Moo Moo Meadows', 'GBA Mario Circuit', 'DS Cheep Cheep Beach', "N64 Toad's Turnpike",
    'GCN Dry Dry Desert', 'SNES Donut Plains 3', 'N64 Royal Raceway', '3DS DK Jungle',
    'DS Wario Stadium', 'GCN Sherbet Land', '3DS Music Park', 'N64 Yoshi Valley',
    'DS Tick-Tock Clock', '3DS Piranha Plant Slide', 'Wii Grumble Volcano', 'N64 Rainbow Road',
    'GCN Yoshi Circuit', 'Excitebike Arena', 'Dragon Driftway', 'Mute City',
    "Wii Wario's Gold Mine", 'SNES Rainbow Road', 'Ice Ice Outpost', 'Hyrule Circuit',
    'GCN Baby Park', 'GBA Cheese Land', 'Wild Woods', 'Animal Crossing',
    '3DS Neo Bowser City', 'GBA Ribbon Road', 'Super Bell Subway','Big Blue'
)

CUPS = {
    'Mushroom': ['Mario Kart Stadium', 'Water Park', 'Sweet Sweet Canyon', 'Thwomp Ruins'],
    'Flower': ['Mario Circuit', 'Toad Harbor', 'Twisted Mansion', 'Shy Guy Falls'],
    'Star': ['Sunshine Airport', 'Dolphin Shoals', 'Electrodrome', 'Mount Wario'],
    'Special': ['Cloudtop Cruise', 'Bone-Dry Dunes', "Bowser's Castle", 'Rainbow Road'],
    'Shell': ['Wii Moo Moo Meadows', 'GBA Mario Circuit', 'DS Cheep Cheep Beach', "N64 Toad's Turnpike"],
    'Banana': ['GCN Dry Dry Desert', 'SNES Donut Plains 3', 'N64 Royal Raceway', '3DS DK Jungle'],
    'Leaf': ['DS Wario Stadium', 'GCN Sherbet Land', '3DS Music Park', 'N64 Yoshi Valley'],
    'Lightning': ['DS Tick-Tock Clock', '3DS Piranha Plant Slide', 'Wii Grumble Volcano', 'N64 Rainbow Road'],
    'Egg': ['GCN Yoshi Circuit', 'Excitebike Arena', 'Dragon Driftway', 'Mute City'],
    'Triforce': ["Wii Wario's Gold Mine", 'SNES Rainbow Road', 'Ice Ice Outpost', 'Hyrule Circuit'],
    'Crossing': ['GCN Baby Park', 'GBA Cheese Land', 'Wild Woods', 'Animal Crossing'],
    'Bell': ['3DS Neo Bowser City', 'GBA Ribbon Road', 'Super Bell Subway','Big Blue']
}

CUPS_ORDER = (
    'Mushroom', 'Flower', 'Star', 'Special', 'Shell', 'Banana', 
    'Leaf', 'Lightning', 'Egg', 'Triforce', 'Crossing', 'Bell'
)

pad = ['Start']
CATEGORIES = {
    'Nitro': pad + list(TRACKS[:-32]),
    'Retro': ['Rainbow Road'] + list(TRACKS[-32:-16]),
    'Bonus': ['N64 Rainbow Road'] + list(TRACKS[-16:]),
    '32': pad + list(TRACKS[:32]),
    '48': pad + list(TRACKS)
}
